module SKUI

  require File.join( PATH, 'control.rb' )


  # @since 1.0.0
  class Button < Control

    # @return [String]
    # @since 1.0.0
    prop( :caption, &TypeCheck::STRING )
    

    # @since 1.0.0
    define_event( :click )
    define_event( :hover )
    
    # @param [String] caption
    # @param [Proc] on_click
    #
    # @since 1.0.0
    def initialize( caption, &on_click )
      super()

      # Default size based on Window UX guidelines.
      #
      # http://msdn.microsoft.com/en-us/library/aa511279.aspx#controlsizing
      # http://msdn.microsoft.com/en-us/library/aa511453.aspx#sizing
      #
      # Actual:  75x23
      # Visible: 73x21
      @properties[ :width ]  = 75
      @properties[ :height ] = 23
      @properties[ :on_hover ] = false

      @properties[ :caption ] = caption

      if block_given?
        add_event_handler( :click, &on_click )
      end
    end
    
    def zone
      px = self.position[0]
      py = self.position[1]
      
      return [Geom::Point3d.new(px,py,0),
      Geom::Point3d.new(px+@properties[ :width ],py,0),
      Geom::Point3d.new(px+@properties[ :width ],py+@properties[ :height ],0),
      Geom::Point3d.new(px,py+@properties[ :height ],0)]
    end
    
    def draw(view) 
      color_fill = [240,240,240]
      color_text = "dimgray"
      if @properties[ :on_hover ]
        color_fill = "tomato"
        color_text = "white"
      else
        color_fill = [240,240,240]
        color_text = "dimgray"
      end
      if !@properties[:enabled]
        color_fill = $color_fill_disabled
        color_text = $color_text_disabled
      end
      @bouder = Rectangle.new
      @bouder.stroke = 0.5
      @bouder.fill = true
      @bouder.color_fill = color_fill
      @bouder.height = @properties[ :height ]
      @bouder.width = @properties[ :width ]
      @bouder.position = self.position
      arc = 2
      
      px = self.position[0]
      py = self.position[1]
      
      p0 = [px,py]
      p1 = [px+@properties[ :width ],py]
      p2 = [px+@properties[ :width ],py+@properties[ :height ]]
      p3 = [px,py+@properties[ :height ]]
      
      @linet = Line.new
      @linet.start  = [p0[0]+arc,p0[1]]
      @linet.end    = [p1[0]-arc,p1[1]]
      
      @lineb = Line.new
      @lineb.start  = [p2[0]-arc,p2[1]]
      @lineb.end    = [p3[0]+arc,p3[1]]
      
      @linel = Line.new
      @linel.start  = [p0[0],p0[1]+arc]
      @linel.end    = [p3[0],p3[1]-arc]
      
      @liner = Line.new
      @liner.start  = [p1[0],p1[1]+arc]
      @liner.end    = [p2[0],p2[1]-arc]
      
      @arc0 = Arc.new
      @arc0.position = [px+3,py+3]
      @arc0.rotate = 180
      @arc0.diameter = 4
      @arc0.type = 0.25
      
      @arc1 = Arc.new
      @arc1.position = [p1[0]-4,p1[1]+3]
      @arc1.rotate = 270
      @arc1.diameter = 4
      @arc1.type = 0.25
      
      @arc2 = Arc.new
      @arc2.position = [p2[0]-4,p2[1]-4]
      #@arc2.rotate = 270
      @arc2.diameter = 4
      @arc2.type = 0.25
      
      @arc3 = Arc.new
      @arc3.position = [p3[0]+3,p3[1]-4]
      @arc3.rotate = 90
      @arc3.diameter = 4
      @arc3.type = 0.25
    
      @bouder.draw(view)
      # @linet.draw(view)
      # @lineb.draw(view)
      # @linel.draw(view)
      # @liner.draw(view)
      # @arc0.draw(view)
      # @arc1.draw(view)
      # @arc2.draw(view)
      # @arc3.draw(view)
      
      options = {
          :font => "Arial",
          :size => 10,
          :bold => true,
          :align => TextAlignCenter,
          :color => color_text
        }
        point = Geom::Point3d.new(@bouder.position[0]+@properties[ :width ]/2, @bouder.position[1]+2, 0)
        view.draw_text(point, @properties[ :caption ], options)
    end
  end # class
end # module