module SKUI

  require File.join( PATH, 'control.rb' )


  # @since 1.0.0
  class Checkbox < Control

    # @return [String]
    # @since 1.0.0
    prop( :label, &TypeCheck::STRING )
    prop( :checked, &TypeCheck::BOOLEAN )

    # @since 1.0.0
    define_event( :change )
    define_event( :click )

    # @param [String] label
    # @param [Boolean] checked
    #
    # @since 1.0.0
    def initialize( label, checked = false )
      super()
      @properties[ :label ]   = label
      @properties[ :checked ] = checked
    end

    # @return [Boolean]
    # @since 1.0.0
    def check
      self.checked = true
      
    end

    # @return [Boolean]
    # @since 1.0.0
    def checked?
      #self.checked = window.bridge.get_checkbox_state( ui_id )
      @properties[ :checked ]
    end

    # @return [Boolean]
    # @since 1.0.0
    def toggle
      self.checked = !checked?
    end

    # @return [Boolean]
    # @since 1.0.0
    def uncheck
      self.checked = false
    end
     
    def zone
      px = self.position[0]
      py = self.position[1]
      
      return [Geom::Point3d.new(px,py,0),
      Geom::Point3d.new(px+15,py,0),
      Geom::Point3d.new(px+15,py+15,0),
      Geom::Point3d.new(px,py+15,0)]
    end
    
    def draw(view) 
    
      color_fill = "white"
      color_text = "dimgray"
      if @properties[ :on_hover ]
        color_fill = "tomato"
        color_text = "white"
      else
        color_fill = "white"
        color_text = "dimgray"
      end
      if !@properties[:enabled]
        color_fill = $color_fill_disabled
        color_text = $color_text_disabled
      end
      
      @bouder = Rectangle.new
      @bouder.stroke = 0.5
      @bouder.fill = true
      @bouder.color_fill = color_fill
      @bouder.height = 15
      @bouder.width = 15
      @bouder.position = [self.position[0], self.position[1]+3]
      @bouder.draw(view)
      
      if @properties[ :checked ]
        px = self.position[0]
        py = self.position[1]
        @tick = Polyline.new
        @tick.list = [[px+2,py+11],[px+7,py+16],[px+14,py+8]]
        @tick.stroke = 3
        @tick.draw(view)
      end
      
      options = {
          :font => "Arial",
          :size => 10,
          :bold => true,
          :align => TextAlignLeft,
          :color => color_text
        }
        point = Geom::Point3d.new(self.position[0]+20, self.position[1]+5, 0)
        view.draw_text(point, @properties[ :label ], options)
    end
  end # class
end # module
