module SKUI

  require File.join( PATH, 'control.rb' )


  # @since 1.0.0
  class Icon < Control

    # @return [Control]
    # @since 1.0.0

    # @return [String]
    # @since 1.0.0
    prop( :icon, &TypeCheck::STRING )
    prop( :active, &TypeCheck::BOOLEAN )
	
    define_event( :click )
    define_event( :hover )
    
    # @param [String] label
    # @param [Control] control Control which focus of forwarded to.
    #
    # @since 1.0.0
    def initialize( icon=nil, label = nil, color = nil)
      super()
      @properties[ :width ]= 24
      @properties[ :height ] = 24
      @properties[ :icon ] = icon
      @properties[ :active ] = false
      
      if block_given?
        add_event_handler( :click, &on_click )
      end
    end
	
	def value
    data = @properties[ :icon ]
    data
  end
  
  def file=(icon)
    @dib_cache = GL_PixelCache.new(0)
    icon = GL_BMP.new( icon )
    @dib_cache.add(icon, self.position[0], self.position[1])
  end
  
  def zone
      px = self.position[0]
      py = self.position[1]
      pts=[Geom::Point3d.new(px,py,0),
      Geom::Point3d.new(px+@properties[ :width ],py,0),
      Geom::Point3d.new(px+@properties[ :width ],py+@properties[ :height ],0),
      Geom::Point3d.new(px,py+@properties[ :height ],0)]
      return pts
    end
    
    def draw(view) 
      
      color_fill = [30, 30, 30, 255]
      color_text = "dimgray"
      if @properties[ :on_hover ]
        color_fill = "tomato"
        color_text = "white"
      else
        color_fill = [30, 30, 30, 255]
        color_text = "dimgray"
      end
      if !@properties[:enabled]
        color_fill = $color_fill_disabled
        color_text = $color_text_disabled
      end
      
      if @properties[ :on_hover ]
        @bouder = Rectangle.new
        @bouder.stroke = 0.5
        @bouder.fill = true
        @bouder.color_fill = "white"
        @bouder.height = @properties[ :height ]+3
        @bouder.width = @properties[ :width ]+3
        @bouder.position = [self.position[0]-1, self.position[1]-1]
        @bouder.draw(view)
      end
      
      if @properties[ :active ]
        @bouder_active = Rectangle.new
        @bouder_active.stroke = 0.5
        @bouder_active.fill = true
        @bouder_active.color_fill = "red"
        @bouder_active.height = @properties[ :height ]+3
        @bouder_active.width = @properties[ :width ]+3
        @bouder_active.position = [self.position[0]-1, self.position[1]-1]
        @bouder_active.draw(view)
      end
      
      
      @dib_cache.draw(view) if @dib_cache
      
    end
  
  end # class
end # module