module SKUI

  require File.join( PATH, 'control.rb' )


  # @since 1.0.0
  class Textbox < Control

    # @return [String]
    # @since 1.0.0
    prop( :value )

    # @return [Boolean]
    # @since 1.0.0
    prop_bool( :multiline, &TypeCheck::BOOLEAN )

    # @return [Boolean]
    # @since 1.0.0
    prop_bool( :readonly, &TypeCheck::BOOLEAN )

    # @return [Boolean]
    # @since 1.0.0
    prop_bool( :password, &TypeCheck::BOOLEAN )

    # @since 1.0.0
    define_event( :click )
    define_event( :change )
    define_event( :textchange )
    define_event( :keydown, :keypress, :keyup )
    define_event( :focus, :blur )
    define_event( :copy, :cut, :paste )
    
    # @param [String] value
    #
    # @since 1.0.0
    def initialize( value = '' )
      super()
      @properties[ :value ] = value
      @properties[ :height ] = 20
      #show inputbox to edit
      self.on( :click ) {}
    end

    # @return [String]
    # @since 1.0.0
    def value
      data = window.bridge.get_value( "##{ui_id} input, ##{ui_id} textarea" )
      @properties[ :value ] = data
      data
    end
    
    def zone
      px = @properties[ :left ]
      py = @properties[ :top ]
      
      return [Geom::Point3d.new(px,py,0),
      Geom::Point3d.new(px+@properties[ :width ],py,0),
      Geom::Point3d.new(px+@properties[ :width ],py+@properties[ :height ],0),
      Geom::Point3d.new(px,py+@properties[ :height ],0)]
    end
    
    
    def draw(view) 
    
      color_fill = "white"
      color_text = "dimgray"
      if @properties[ :on_hover ]
        color_fill = "white"
      else
        color_fill = "white"
      end
      if !@properties[:enabled]
        color_fill = $color_fill_disabled
        color_text = $color_text_disabled
      end
      
      @bouder = Rectangle.new
      @bouder.stroke = 0.5
      @bouder.fill = true
      @bouder.color_fill = color_fill
      @bouder.height = @properties[ :height ]
      @bouder.width = @properties[ :width ]
      @bouder.position = self.position
      @bouder.draw(view)
      
      px = @properties[ :left ]
      py = @properties[ :top ]
      
      # options = {
          # :font => "Arial",
          # :size => 10,
          # :bold => true,
          # :align => TextAlignRight,
          # :color => color_text
        # }
        # point = Geom::Point3d.new(self.position[0]-3, self.position[1]+3, 0)
        # view.draw_text(point, @lable, options)
        
      options = {
          :font => "Arial",
          :size => 10,
          :bold => false,
          :align => TextAlignLeft,
          :color => color_text
        }
        point = Geom::Point3d.new(self.position[0]+2, self.position[1]+3, 0)
        view.draw_text(point, @properties[ :value ].to_s, options)

    end
    
  end # class
end # module
