module SKUI

  require File.join( PATH, 'control.rb' )


  # @since 1.0.0
  class Toggle < Control

    # @return [String]
    # @since 1.0.0
    prop( :label, &TypeCheck::STRING )
    prop( :checked, &TypeCheck::BOOLEAN )

    # @since 1.0.0
    define_event( :change )
    define_event( :click )

    # @param [String] label
    # @param [Boolean] checked
    #
    # @since 1.0.0
    def initialize( label, checked = false )
      super()
      @properties[ :label ]   = label
      @properties[ :checked ] = checked
    end

    # @return [Boolean]
    # @since 1.0.0
    def check
      self.checked = true
      
    end

    # @return [Boolean]
    # @since 1.0.0
    def checked?
      #self.checked = window.bridge.get_checkbox_state( ui_id )
      @properties[ :checked ]
    end

    # @return [Boolean]
    # @since 1.0.0
    def toggle
      self.checked = !checked?
    end

    # @return [Boolean]
    # @since 1.0.0
    def uncheck
      self.checked = false
    end
     
    def zone
      px = self.position[0]
      py = self.position[1]
      
      return [Geom::Point3d.new(px,py,0),
      Geom::Point3d.new(px+30,py,0),
      Geom::Point3d.new(px+30,py+30,0),
      Geom::Point3d.new(px,py+30,0)]
    end
    
    def draw(view) 
    
      color_fill = "red"
      color_text = "dimgray"
      
      # if @properties[ :on_hover ]
        # color_fill = "tomato"
        # color_text = "white"
      # else
        # color_fill = "white"
        # color_text = "dimgray"
      # end
      
      if @properties[:checked]
        color_checked = "white"
        color_fill = "red"
      else
        color_checked = "red"
        color_fill = "white"
      end
      
      if !@properties[:enabled]
        color_fill = $color_fill_disabled
        color_text = $color_text_disabled
        color_checked = $color_text_disabled
      end
      
      ############
      @acr_left = Circle.new
      @acr_left.position = [self.position[0]+7.5, self.position[1]+5+6]
      @acr_left.diameter = 7.5
      @acr_left.stroke = 0.5
      @acr_left.fill = true
      @acr_left.color_fill = color_fill
      @acr_left.draw(view)
      
      @acr_right = Circle.new
      @acr_right.position = [self.position[0]+7.5+14, self.position[1]+5+6]
      @acr_right.diameter = 7.5
      @acr_right.stroke = 0.5
      @acr_right.fill = true
      @acr_right.color_fill = color_fill
      @acr_right.draw(view)
      
      @bouder = Rectangle.new
      @bouder.stroke = 0
      @bouder.fill = true
      @bouder.color_fill = color_fill
      @bouder.height = 15
      @bouder.width = 15
      @bouder.position = [self.position[0]+7.5, self.position[1]+4]
      @bouder.draw(view)
      
      position = @bouder.position
      px = position[0]
      py = position[1]
      
      p0 = [px,py]
      p1 = [px+15,py]
      p2 = [px+15,py+15]
      p3 = [px,py+15]
      
      @linet = Line.new
      @linet.start  = [p0[0],p0[1]]
      @linet.end    = [p1[0],p1[1]]
      
      @lineb = Line.new
      @lineb.start  = [p2[0]-1,p2[1]-0.5]
      @lineb.end    = [p3[0]-1,p3[1]-0.5]
      @linet.draw(view)
      @lineb.draw(view)
      
      @circle = Circle.new
      if @properties[:checked]
        @circle.position = [self.position[0]+7.5+13, self.position[1]+5+6]
      else
        @circle.position = [self.position[0]+7.5+14-13, self.position[1]+5+6]
      end
      @circle.diameter = 6
      @circle.stroke = 1
      @circle.fill = true
      @circle.color_fill = color_checked
      @circle.draw(view)
      #########
      options = {
          :font => "Arial",
          :size => 10,
          :bold => true,
          :align => TextAlignLeft,
          :color => color_text
        }
        point = Geom::Point3d.new(self.position[0]+35, self.position[1]+5, 0)
        view.draw_text(point, @properties[ :label ], options)
    end
  end # class
end # module
